@@ -7,7 +7,6 @@ information, etc.
 
 ##############################################################################
 # Local imports.
-from .base import Command
 from .collection import (
     SearchCollections,
     ShowAll,
@@ -20,13 +19,10 @@ from .filtering import (
     SearchTags,
 )
 from .main import (
-    ChangeTheme,
     CompactMode,
     Details,
     Escape,
-    Help,
     Logout,
-    Quit,
     Redownload,
     TagOrder,
     VisitRaindrop,
@@ -43,9 +39,7 @@ from .raindrop import (
 ##############################################################################
 # Exports.
 __all__ = [
-    "Command",
     "AddRaindrop",
-    "ChangeTheme",
     "CheckTheWaybackMachine",
     "ClearFilters",
     "CompactMode",
@@ -54,9 +48,7 @@ __all__ = [
     "Details",
     "EditRaindrop",
     "Escape",
-    "Help",
     "Logout",
-    "Quit",
     "Redownload",
     "Search",
     "SearchCollections",
