@@ -1,8 +1,8 @@
 """Provides command-oriented messages that relate to the collections."""
 
 ##############################################################################
-# Local imports.
-from .base import Command
+# Textual enhanced imports.
+from textual_enhanced.commands import Command
 
 
 ##############################################################################
@@ -10,7 +10,6 @@ class SearchCollections(Command):
     """Search for a collection by name and show its contents"""
 
     BINDING_KEY = "C"
-    SHOW_IN_FOOTER = False
 
 
 ##############################################################################
@@ -18,7 +17,6 @@ class ShowAll(Command):
     """Show all Raindrops"""
 
     BINDING_KEY = "a"
-    SHOW_IN_FOOTER = False
 
 
 ##############################################################################
@@ -26,7 +24,6 @@ class ShowUnsorted(Command):
     "Show all unsorted Raindrops"
 
     BINDING_KEY = "u"
-    SHOW_IN_FOOTER = False
 
 
 ##############################################################################
@@ -34,7 +31,6 @@ class ShowUntagged(Command):
     """Show all Raindrops that are lacking tags"""
 
     BINDING_KEY = "U"
-    SHOW_IN_FOOTER = False
 
 
 ### collection.py ends here
