@@ -1,8 +1,8 @@
 """Provides command-oriented messages that affect the raindrops."""
 
 ##############################################################################
-# Local imports.
-from .base import Command
+# Textual enhanced imports.
+from textual_enhanced.commands import Command
 
 
 ##############################################################################
@@ -10,7 +10,6 @@ class AddRaindrop(Command):
     """Add a new raindrop"""
 
     BINDING_KEY = "n"
-    SHOW_IN_FOOTER = False
 
 
 ##############################################################################
@@ -18,7 +17,6 @@ class CheckTheWaybackMachine(Command):
     """Check if the currently-highlighted raindrop is archived in the Wayback Machine"""
 
     BINDING_KEY = "w"
-    SHOW_IN_FOOTER = False
 
 
 ##############################################################################
@@ -26,7 +24,6 @@ class CopyLinkToClipboard(Command):
     """Copy the currently-highlighted link to the clipboard"""
 
     BINDING_KEY = "c"
-    SHOW_IN_FOOTER = False
 
 
 ##############################################################################
@@ -34,7 +31,6 @@ class DeleteRaindrop(Command):
     """Delete the currently-highlighted raindrop"""
 
     BINDING_KEY = "d, delete"
-    SHOW_IN_FOOTER = False
 
 
 ##############################################################################
@@ -42,7 +38,6 @@ class EditRaindrop(Command):
     """Edit the currently-highlighted raindrop"""
 
     BINDING_KEY = "e"
-    SHOW_IN_FOOTER = False
 
 
 ##############################################################################
@@ -50,7 +45,6 @@ class VisitLink(Command):
     """Visit currently-highlighted link"""
 
     BINDING_KEY = "v"
-    SHOW_IN_FOOTER = False
 
 
 ### raindrop.py ends here
