@@ -9,7 +9,8 @@ from .config import (
     update_configuration,
 )
 from .exit_state import ExitState
-from .local import LocalData, Raindrops, local_data_file
+from .local import LocalData, local_data_file
+from .raindrops import Raindrops, TagCount, TypeCount
 from .token import token_file
 
 ##############################################################################
@@ -21,6 +22,8 @@ __all__ = [
     "local_data_file",
     "LocalData",
     "Raindrops",
+    "TagCount",
+    "TypeCount",
     "save_configuration",
     "token_file",
     "update_configuration",
