@@ -3,12 +3,11 @@
 ##############################################################################
 # Local imports.
 from .collections import CollectionCommands
-from .commands_provider import CommandsProvider
 from .main import MainCommands
 from .tags import TagCommands
 
 ##############################################################################
 # Exports.
-__all__ = ["CollectionCommands", "CommandsProvider", "MainCommands", "TagCommands"]
+__all__ = ["CollectionCommands", "MainCommands", "TagCommands"]
 
 ### __init__.py ends here
