@@ -2,12 +2,11 @@
 
 ##############################################################################
 # Local imports.
-from .downloading import Downloading
 from .main import Main
 from .token_input import TokenInput
 
 ##############################################################################
 # Exports.
-__all__ = ["Downloading", "Main", "TokenInput"]
+__all__ = ["Main", "TokenInput"]
 
 ### __init__.py ends here
