@@ -14,11 +14,14 @@ from pyperclip import copy as to_clipboard
 # Textual imports.
 from textual import on, work
 from textual.app import ComposeResult
-from textual.command import CommandPalette
-from textual.containers import Horizontal
 from textual.reactive import var
-from textual.screen import Screen
 from textual.widgets import Footer, Header
+from textual_enhanced.commands import ChangeTheme, Command, Help, Quit
+
+##############################################################################
+# Textual enhanced imports.
+from textual_enhanced.dialogs import Confirm, ModalInput
+from textual_enhanced.screen import EnhancedScreen
 
 ##############################################################################
 # Typing extension imports.
@@ -30,19 +33,15 @@ from ... import __version__
 from ...raindrop import API, Raindrop, SpecialCollection, User
 from ..commands import (
     AddRaindrop,
-    ChangeTheme,
     CheckTheWaybackMachine,
     ClearFilters,
-    Command,
     CompactMode,
     CopyLinkToClipboard,
     DeleteRaindrop,
     Details,
     EditRaindrop,
     Escape,
-    Help,
     Logout,
-    Quit,
     Redownload,
     Search,
     SearchCollections,
@@ -60,23 +59,19 @@ from ..data import (
     Raindrops,
     load_configuration,
     local_data_file,
-    save_configuration,
     token_file,
     update_configuration,
 )
-from ..messages import ShowCollection, ShowTagged
-from ..providers import CollectionCommands, CommandsProvider, MainCommands, TagCommands
+from ..messages import ShowCollection, ShowOfType, ShowTagged
+from ..providers import CollectionCommands, MainCommands, TagCommands
 from ..widgets import Navigation, RaindropDetails, RaindropsView
-from .confirm import Confirm
 from .downloading import Downloading
-from .help import HelpScreen
 from .raindrop_input import RaindropInput
-from .search_input import SearchInput
 from .wayback_checker import WaybackChecker
 
 
 ##############################################################################
-class Main(Screen[None]):
+class Main(EnhancedScreen[None]):
     """The main screen of the application."""
 
     TITLE = f"Braindrop v{__version__}"
@@ -89,28 +84,10 @@ class Main(Screen[None]):
 
     DEFAULT_CSS = """
     Main {
-        Navigation {
-            width: 2fr;
-            height: 1fr;
-            &> .option-list--option {
-                padding: 0 1;
-            }
-        }
+        layout: horizontal;
 
-        RaindropsView {
-            width: 5fr;
+        .panel {
             height: 1fr;
-            &> .option-list--option {
-                padding: 0 1;
-            }
-        }
-
-        RaindropDetails {
-            width: 3fr;
-            height: 1fr;
-        }
-
-        .focus {
             padding-right: 0;
             border: none;
             border-left: round $border 50%;
@@ -127,6 +104,22 @@ class Main(Screen[None]):
                 scrollbar-background-hover: $panel;
                 scrollbar-background-active: $panel;
             }
+            &> .option-list--option {
+                padding: 0 1;
+            }
+        }
+
+        Navigation {
+            width: 2fr;
+        }
+
+        RaindropsView {
+            width: 5fr;
+            scrollbar-gutter: stable;
+        }
+
+        RaindropDetails {
+            width: 3fr;
         }
 
         /* For when the details are hidden. */
@@ -177,6 +170,9 @@ class Main(Screen[None]):
     active_collection: var[Raindrops] = var(Raindrops, always_update=True)
     """The currently-active collection."""
 
+    highlighted_raindrop: var[Raindrop | None] = var(None)
+    """The currently-highlighted raindrop."""
+
     def __init__(self, api: API) -> None:
         """Initialise the main screen.
 
@@ -199,14 +195,11 @@ class Main(Screen[None]):
     def compose(self) -> ComposeResult:
         """Compose the content of the screen."""
         yield Header()
-        with Horizontal():
-            yield Navigation(self._api, classes="focus").data_bind(
-                Main.active_collection
-            )
-            yield RaindropsView(classes="focus").data_bind(
-                raindrops=Main.active_collection
-            )
-            yield RaindropDetails(classes="focus")
+        yield Navigation(self._api, classes="panel").data_bind(Main.active_collection)
+        yield RaindropsView(classes="panel").data_bind(raindrops=Main.active_collection)
+        yield RaindropDetails(classes="panel").data_bind(
+            raindrop=Main.highlighted_raindrop
+        )
         yield Footer()
 
     @work
@@ -241,7 +234,9 @@ class Main(Screen[None]):
             )
             return
 
-        if self._data.last_downloaded is None:
+        if self._data.outdated_format:
+            self.notify("Local file format has changed; rebuilding from the server.")
+        elif self._data.last_downloaded is None:
             self.notify("No local data found; checking in with the server.")
         elif (
             self._user.last_update is not None
@@ -289,7 +284,7 @@ class Main(Screen[None]):
         config = load_configuration()
         self.set_class(not config.details_visible, "details-hidden")
         self.query_one(Navigation).tags_by_count = config.show_tags_by_count
-        self.query_one(RaindropsView).compact = config.compact_mode
+        self.query_one(RaindropsView).compact_view = config.compact_mode
         self.load_data()
 
     def watch_active_collection(self) -> None:
@@ -309,19 +304,6 @@ class Main(Screen[None]):
         self.active_collection = self._data.all
         self.query_one(Navigation).highlight_collection(SpecialCollection.ALL())
 
-    def _show_palette(self, provider: type[CommandsProvider]) -> None:
-        """Show a particular command palette.
-
-        Args:
-            provider: The commands provider for the palette.
-        """
-        self.app.push_screen(
-            CommandPalette(
-                providers=(provider,),
-                placeholder=provider.prompt(),
-            )
-        )
-
     @on(ShowCollection)
     def command_show_collection(self, command: ShowCollection) -> None:
         """Handle the command that requests we show a collection.
@@ -332,22 +314,29 @@ class Main(Screen[None]):
         self.active_collection = self._data.in_collection(command.collection)
         self.query_one(Navigation).highlight_collection(command.collection)
 
-    @on(SearchCollections)
     def action_search_collections_command(self) -> None:
         """Show the collection-based command palette."""
-        self._show_palette(CollectionCommands)
+        self.show_palette(CollectionCommands)
 
-    @on(SearchTags)
     def action_search_tags_command(self) -> None:
         """Show the tags-based command palette."""
         if self.active_collection.tags:
-            self._show_palette(TagCommands)
+            self.show_palette(TagCommands)
         else:
             self.notify(
                 f"The '{self.active_collection.title}' collection has no tags",
                 severity="information",
             )
 
+    @on(ShowOfType)
+    def command_show_of_type(self, command: ShowOfType) -> None:
+        """handle the command that requests we show Raindrops of a given type.
+
+        Args:
+            command: The command.
+        """
+        self.active_collection = self.active_collection.of_type(command.raindrop_type)
+
     @on(ShowTagged)
     def command_show_tagged(self, command: ShowTagged) -> None:
         """Handle the command that requests we show Raindrops with a given tag.
@@ -357,24 +346,25 @@ class Main(Screen[None]):
         """
         self.active_collection = self.active_collection.tagged(command.tag)
 
-    @on(RaindropsView.OptionHighlighted)
-    def update_details(self) -> None:
-        """Update the details panel to show the current raindrop."""
-        self.query_one(RaindropDetails).raindrop = self.query_one(
-            RaindropsView
-        ).highlighted_raindrop
+    @on(RaindropsView.Empty)
+    def deselect_raindrop(self) -> None:
+        """Handle that there is no selected Raindrop."""
+        self.highlighted_raindrop = None
+
+    @on(RaindropsView.Highlighted)
+    def highlight_raindrop(self, message: RaindropsView.Highlighted) -> None:
+        """Handle the highlighted raindrop changing."""
+        self.highlighted_raindrop = message.raindrop
 
     @on(Redownload)
     def action_redownload_command(self) -> None:
         """Redownload data from the server."""
         self.download_data()
 
-    @on(VisitRaindrop)
     def action_visit_raindrop_command(self) -> None:
         """Open the Raindrop application in the browser."""
         open_url("https://app.raindrop.io/")
 
-    @on(TagOrder)
     def action_tag_order_command(self) -> None:
         """Toggle the ordering of tags."""
         self.query_one(Navigation).tags_by_count = (
@@ -383,27 +373,22 @@ class Main(Screen[None]):
         with update_configuration() as config:
             config.show_tags_by_count = by_count
 
-    @on(ShowAll)
     def action_show_all_command(self) -> None:
         """Select the collection that shows all Raindrops."""
         self.query_one(Navigation).show_all()
 
-    @on(ShowUnsorted)
     def action_show_unsorted_command(self) -> None:
         """Select the collection that shows all unsorted Raindrops."""
         self.query_one(Navigation).show_unsorted()
 
-    @on(ShowUntagged)
     def action_show_untagged_command(self) -> None:
         """Select the collection that shows all untagged Raindrops."""
         self.query_one(Navigation).show_untagged()
 
-    @on(ClearFilters)
     def action_clear_filters_command(self) -> None:
         """Remove any filtering from the active collection."""
         self.active_collection = self.active_collection.unfiltered
 
-    @on(Escape)
     def action_escape_command(self) -> None:
         """Handle escaping.
 
@@ -422,30 +407,37 @@ class Main(Screen[None]):
         else:
             self.app.exit()
 
-    @on(Details)
     def action_details_command(self) -> None:
         """Toggle the details of the raindrop details view."""
         self.toggle_class("details-hidden")
+        if (
+            hidden := self.has_class("details-hidden")
+            and self.focused is not None
+            and self.query_one(RaindropDetails) in (self.focused, self.focused.parent)
+        ):
+            # Focus was on the details, or within, so let's ensure it heads
+            # back to the list of raindrops as that feels like the most
+            # logical landing point.
+            self.set_focus(self.query_one(RaindropsView))
         with update_configuration() as config:
-            config.details_visible = not self.has_class("details-hidden")
+            config.details_visible = not hidden
 
-    @on(CompactMode)
     def action_compact_mode_command(self) -> None:
         """Toggle the compact mode for the list of raindrops."""
-        self.query_one(RaindropsView).compact = not self.query_one(
+        self.query_one(RaindropsView).compact_view = not self.query_one(
             RaindropsView
-        ).compact
+        ).compact_view
         with update_configuration() as config:
-            config.compact_mode = self.query_one(RaindropsView).compact
+            config.compact_mode = self.query_one(RaindropsView).compact_view
 
-    @on(Search)
     @work
     async def action_search_command(self) -> None:
         """Free-text search within the Raindrops."""
-        if search_text := await self.app.push_screen_wait(SearchInput()):
+        if search_text := await self.app.push_screen_wait(
+            ModalInput("Case-insensitive text to look for in the Raindrops")
+        ):
             self.active_collection = self.active_collection.containing(search_text)
 
-    @on(Logout)
     @work
     async def action_logout_command(self) -> None:
         """Perform the logout action."""
@@ -459,17 +451,6 @@ class Main(Screen[None]):
             local_data_file().unlink(True)
             self.app.exit(ExitState.TOKEN_FORGOTTEN)
 
-    @on(Help)
-    def action_help_command(self) -> None:
-        """Toggle the display of the help panel."""
-        self.app.push_screen(HelpScreen(self))
-
-    @on(ChangeTheme)
-    def action_change_theme_command(self) -> None:
-        """Show the theme picker."""
-        self.app.search_themes()
-
-    @on(Quit)
     def action_quit_command(self) -> None:
         """Quit the application."""
         self.app.exit(ExitState.OKAY)
@@ -483,7 +464,7 @@ class Main(Screen[None]):
         Returns:
             The highlighted raindrop, or `None`.
         """
-        if (raindrop := self.query_one(RaindropsView).highlighted_raindrop) is None:
+        if (raindrop := self.highlighted_raindrop) is None:
             self.notify(
                 f"No Raindrop is highlighted, there is nothing to {action}!",
                 title="No Raindrop",
@@ -519,7 +500,6 @@ class Main(Screen[None]):
             return
         open_url(link)
 
-    @on(CopyLinkToClipboard)
     def action_copy_link_to_clipboard_command(self) -> None:
         """Copy the currently-highlighted link to the clipboard."""
 
@@ -546,7 +526,6 @@ class Main(Screen[None]):
         else:
             self.notify("The link has been copied to the clipboard")
 
-    @on(CheckTheWaybackMachine)
     def action_check_the_wayback_machine_command(self) -> None:
         """Check if the current raindrop is on the Wayback Machine."""
         if (link := self._current_link("check")) is None:
@@ -599,7 +578,6 @@ class Main(Screen[None]):
             # Let the user know what happened.
             self.notify(confirmation)
 
-    @on(AddRaindrop)
     @work
     async def action_add_raindrop_command(self) -> None:
         """Add a new Raindrop."""
@@ -635,7 +613,6 @@ class Main(Screen[None]):
         # We're safe to drop the draft now.
         self._draft_raindrop = None
 
-    @on(EditRaindrop)
     @work
     async def action_edit_raindrop_command(self) -> None:
         """Edit the currently-highlighted raindrop."""
@@ -645,6 +622,20 @@ class Main(Screen[None]):
         if (raindrop := self._current_raindrop("edit")) is None:
             return
 
+        # For the moment, don't allow editing of uploaded images.
+        # https://github.com/davep/braindrop/issues/123
+        if raindrop.domain == "up.raindrop.io":
+            self.notify(
+                "There seems to be a problem with the Raindrop API where, "
+                "if you modify a Raindrop associated with an uploaded file, "
+                "the uploaded file is lost.\n\n"
+                "To ensure your file isn't lost this edit is not permitted.",
+                title="Editing of uploads disabled",
+                severity="warning",
+                timeout=8,
+            )
+            return
+
         # If we've got a draft, and it's for the current raindrop...
         if (
             self._draft_raindrop is not None
@@ -682,7 +673,6 @@ class Main(Screen[None]):
         # We're safe to drop the draft now.
         self._draft_raindrop = None
 
-    @on(DeleteRaindrop)
     @work
     async def action_delete_raindrop_command(self) -> None:
         """Delete the currently-highlighted raindrop."""
