@@ -6,7 +6,7 @@ from .api import API
 from .collection import Collection, SpecialCollection
 from .raindrop import Raindrop, RaindropType
 from .suggestions import Suggestions
-from .tag import Tag, TagData
+from .tag import Tag
 from .time_tools import get_time
 from .user import Group, User
 
@@ -22,7 +22,6 @@ __all__ = [
     "SpecialCollection",
     "Suggestions",
     "Tag",
-    "TagData",
     "User",
 ]
 
